==> dd_yandex_pay-0.1.0b0.tar.gz: dd_yandex_pay-0.1.0b0/README.md <==
<h1 align="center" >DD Yandex Pay</h1>

<p align="center">
	<!-- <a href="https://pypi.org/project/dd_yandex_pay">
		<img src="https://img.shields.io/pypi/status/dd_yandex_pay.svg" alt="PyPI - Status" />
	</a> -->
	<!-- <a href="https://pypi.org/project/dd_yandex_pay">
		<img src="https://img.shields.io/pypi/v/dd_yandex_pay.svg" alt="PyPI - Version" />
	</a> -->
	<!-- <a href="https://pypi.org/project/dd_yandex_pay">
		<img src="https://img.shields.io/pypi/dm/dd_yandex_pay.svg" alt="PyPI - Downloads" />
	</a> -->
	<!-- <a href="https://pypi.org/project/dd_yandex_pay">
		<img src="https://img.shields.io/pypi/pyversions/dd_yandex_pay.svg" alt="PyPI - Python Version" />
	</a> -->
	<!-- <a href="https://pypi.org/project/dd_yandex_pay">
		<img src="https://img.shields.io/pypi/format/dd_yandex_pay.svg" alt="PyPI - Format" />
	</a> -->
</p>
<p align="center">
	<a href="https://github.com/dd/dd_yandex_pay/actions/workflows/mkdocs-release.yml" >
		<img src="https://img.shields.io/github/actions/workflow/status/dd/dd_yandex_pay/mkdocs-release.yml?logo=github&label=docs" alt="Documentation - Release" />
	</a>
	<a href="https://github.com/dd/dd_yandex_pay/actions/workflows/test.yml" >
		<img src="https://img.shields.io/github/actions/workflow/status/dd/dd_yandex_pay/test.yml?logo=github&label=tests" alt="Tests - Running" />
	</a>
	<a href="https://codecov.io/gh/dd/dd_yandex_pay" >
		<img src="https://codecov.io/gh/dd/dd_yandex_pay/branch/main/graph/badge.svg?token=HV1QGD74EK" alt="Tests - Coverage" />
	</a>
</p>
<p align="center">
	<a href="https://github.com/pypa/hatch" target="_blank">
		<img src="https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg" alt="Hatch project" />
	</a>
	<a href="https://squidfunk.github.io/mkdocs-material/" target="_blank">
		<img src="https://img.shields.io/badge/docs-mkdocs_material-blue?logo=mdbook&logoColor=white" alt="Material for MkDocs" />
	</a>
	<a href="https://github.com/charliermarsh/ruff" target="_blank">
		<img src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json" alt="linting - Ruff" />
	</a>
	<a href="https://github.com/psf/black" target="_blank">
		<img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="code style - black" />
	</a>
	<!-- <a href="https://raw.githubusercontent.com/dd/dd_yandex_pay/main/LICENSE" target="_blank">
		<img src="https://img.shields.io/pypi/l/dd_yandex_pay?color=008033" alt="License - GNU Lesser General Public License v3.0" />
	</a> -->
</p>

Wrapper for [Yandex Pay API](https://pay.yandex.ru/ru/docs/custom/backend/yandex-pay-api/).

However, if someone decides to use this functionality in their project, and even more so to add functionality or change the implementation to a more correct, beautiful or understandable one, I will only be happy, do not worry and feel free to write to me by [mail](mailto:dd@tovarisch.engineer), create an [issue](https://github.com/dd/dd_yandex_pay/issues) or [pull request](https://github.com/dd/dd_yandex_pay/pulls) on [github](https://github.com/dd/dd_yandex_pay).

==> dd_yandex_pay-0.3.0.tar.gz: dd_yandex_pay-0.3.0/README.md <==
<h1 align="center" >DD Yandex Pay</h1>

<p align="center">
	<a href="https://pypi.org/project/dd_yandex_pay">
		<img src="https://img.shields.io/pypi/status/dd_yandex_pay.svg" alt="PyPI - Status" />
	</a>
	<a href="https://pypi.org/project/dd_yandex_pay">
		<img src="https://img.shields.io/pypi/v/dd_yandex_pay.svg" alt="PyPI - Version" />
	</a>
	<a href="https://pypi.org/project/dd_yandex_pay">
		<img src="https://img.shields.io/pypi/dm/dd_yandex_pay.svg" alt="PyPI - Downloads" />
	</a>
	<a href="https://pypi.org/project/dd_yandex_pay">
		<img src="https://img.shields.io/pypi/pyversions/dd_yandex_pay.svg" alt="PyPI - Python Version" />
	</a>
	<a href="https://pypi.org/project/dd_yandex_pay">
		<img src="https://img.shields.io/pypi/format/dd_yandex_pay.svg" alt="PyPI - Format" />
	</a>
</p>
<p align="center">
	<a href="https://github.com/dd/dd_yandex_pay/actions/workflows/mkdocs-release.yml" >
		<img src="https://img.shields.io/github/actions/workflow/status/dd/dd_yandex_pay/mkdocs-release.yml?logo=github&label=docs" alt="Documentation - Release" />
	</a>
	<a href="https://github.com/dd/dd_yandex_pay/actions/workflows/test.yml" >
		<img src="https://img.shields.io/github/actions/workflow/status/dd/dd_yandex_pay/test.yml?logo=github&label=tests" alt="Tests - Running" />
	</a>
	<a href="https://codecov.io/gh/dd/dd_yandex_pay" >
		<img src="https://codecov.io/gh/dd/dd_yandex_pay/branch/main/graph/badge.svg?token=HV1QGD74EK" alt="Tests - Coverage" />
	</a>
</p>
<p align="center">
	<a href="https://github.com/pypa/hatch" target="_blank">
		<img src="https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg" alt="Hatch project" />
	</a>
	<a href="https://squidfunk.github.io/mkdocs-material/" target="_blank">
		<img src="https://img.shields.io/badge/docs-mkdocs_material-blue?logo=mdbook&logoColor=white" alt="Material for MkDocs" />
	</a>
	<a href="https://github.com/charliermarsh/ruff" target="_blank">
		<img src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json" alt="linting - Ruff" />
	</a>
	<a href="https://github.com/psf/black" target="_blank">
		<img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="code style - black" />
	</a>
	<a href="https://raw.githubusercontent.com/dd/dd_yandex_pay/main/LICENSE" target="_blank">
		<img src="https://img.shields.io/pypi/l/dd_yandex_pay?color=008033" alt="License - GNU Lesser General Public License v3.0" />
	</a>
</p>

Wrapper for [Yandex Pay API](https://pay.yandex.ru/ru/docs/custom/backend/yandex-pay-api/).

For a detailed description of how to work with the client, read the [usage](https://dd.github.io/dd_yandex_pay/usage/getting_started/) section in the [documentation](https://dd.github.io/dd_yandex_pay/).

You can leave any suggestions for the development of the project in [discussions](https://github.com/dd/dd_yandex_pay/discussions) on GitHub.

If you come across a bug, please open an [issue](https://github.com/dd/dd_yandex_pay/issues).

If you would like to contribute to the development of the project, please read the [contribution](https://dd.github.io/dd_yandex_pay/contributing/) section in the documentation.
